@@ -77,8 +77,8 @@ class ChromeDriver(BaseDriver, WebDriver):
             prefs.update({"profile.managed_default_content_settings.images": 2})
 
         chrome_options.add_experimental_option('prefs', prefs)
-        # super().__init__(executable_path=executable_path, desired_capabilities=d, options=chrome_options)
         super().__init__(executable_path=executable_path, options=chrome_options)
+        # super().__init__(executable_path=executable_path, options=chrome_options)
         self.execute_cdp_cmd("Page.addScriptToEvaluateOnNewDocument", {
             "source": """
             Object.defineProperty(navigator, 'webdriver', {
@@ -90,5 +90,5 @@ class ChromeDriver(BaseDriver, WebDriver):
             "userAgent": "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/91.0.4472.77 Safari/537.36"
             # "userAgent": "Mozilla/5.0 (iPhone; CPU iPhone OS 15_0_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 micromessenger/8.0.15(0x18000f27) NetType/4G Language/zh_CN"
         })
-        # self.set_window_position(0, 0)
-        # self.set_window_size(1200, 1000)
+        self.set_window_position(0, 0)
+        self.set_window_size(1200, 1000)
