@@ -101,12 +101,8 @@ class BaseConnection(object):
         :return:
         """
         params = kwargs.get("params", None)
-        page_end = kwargs["page_end"]
-        if page_end is None:
-            page_end = page_start + 1
-        add_headers = kwargs["add_headers"]
-        if add_headers is None:
-            add_headers = False
+        page_end = kwargs.get("page_end", page_start + 1)
+        add_headers = kwargs.get("add_headers", False)
 
         start = page_size * (page_start - 1)
         end = page_size * (page_end - page_start)
